// swift-tools-version:5.4
import PackageDescription

let checksum = "24d3d6a0364adef008bf33549751dee847b09d6b046666e955480805ca508d9a"
let version = "v91.0.0"
let url = "https://github.com/mozilla/application-services/releases/download/\(version)/MozillaRustComponents.xcframework.zip"

let package = Package(
    name: "MozillaRustComponentsSwift",
    platforms: [.iOS(.v11)],
    products: [
        .library(name: "RustLog", targets: ["RustLog"]),
        .library(name: "Viaduct", targets: ["Viaduct"]),
        .library(name: "Nimbus", targets: ["Nimbus"]),
        .library(name: "CrashTest", targets: ["CrashTest"]),
        .library(name: "Logins", targets: ["Logins"]),
        .library(name: "FxAClient", targets: ["FxAClient"]),
        .library(name: "Autofill", targets: ["Autofill"]),
        .library(name: "Push", targets: ["Push"]),
        .library(name: "Tabs", targets: ["Tabs"]),
        .library(name: "Places", targets: ["Places"]),
    ],
    dependencies: [
    ],
    targets: [
        /*
        * A placeholder wrapper for our binaryTarget so that Xcode will ensure this is
        * downloaded/built before trying to use it in the build process
        * A bit hacky but necessary for now https://github.com/mozilla/application-services/issues/4422
        */
        .target(
            name: "MozillaRustComponentsWrapper",
            dependencies: [
                .target(name: "MozillaRustComponents", condition: .when(platforms: [.iOS]))
            ],
            path: "MozillaRustComponentsWrapper"
        ),
        .binaryTarget(
            name: "MozillaRustComponents",
            //
            // For release artifacts, reference the MozillaRustComponents as a URL with checksum.
            // IMPORTANT: The checksum has to be on the line directly after the `url`
            // this is important for our release script so that all values are updated correctly
            url: url,
            checksum: checksum

            // For local testing, you can point at an (unzipped) XCFramework that's part of the repo.
            // Note that you have to actually check it in and make a tag for it to work correctly.
            //
            //path: "./MozillaRustComponents.xcframework"
        ),
        .target(
            name: "Sync15",
            path: "generated/sync15"
        ),
        .target(
            name: "RustLog",
            dependencies: ["MozillaRustComponentsWrapper"],
            path: "generated/rc_log"
        ),
        .target(
            name: "Viaduct",
            dependencies: ["MozillaRustComponentsWrapper"],
            path: "generated/viaduct"
        ),
        .target(
            name: "Nimbus",
            dependencies: ["MozillaRustComponentsWrapper"],
            path: "generated/nimbus"
        ),
        .target(
            name: "CrashTest",
            dependencies: ["MozillaRustComponentsWrapper"],
            path: "generated/crashtest"
        ),
        .target(
           name: "Logins",
           dependencies: ["MozillaRustComponentsWrapper", "Sync15"],
           path: "generated/logins"
        ),
        .target(
           name: "FxAClient",
           dependencies: ["MozillaRustComponentsWrapper"],
           path: "generated/fxa-client"
        ),
        .target(
            name: "Autofill",
            dependencies: ["MozillaRustComponentsWrapper"],
            path: "generated/autofill"
        ),
        .target(
            name: "Push",
            dependencies: ["MozillaRustComponentsWrapper"],
            path: "generated/push"
        ),
        .target(
            name: "Tabs",
            dependencies: ["MozillaRustComponentsWrapper"],
            path: "generated/tabs"
        ),
        .target(
            name: "Places",
            dependencies: ["MozillaRustComponentsWrapper", "Sync15"],
            path: "generated/places"
        )
    ]
)
